==> qesteidutil-0.1.99.1586.tar.bz2: qesteidutil-0.1.99.1586/common/translations/common_ru.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS><TS version="1.1" language="ru">
<defaultcodec></defaultcodec>
<context>
    <name>CertificateDialog</name>
    <message>
        <source>Save certificate</source>
        <translation>Сохранить сертификат</translation>
    </message>
    <message>
        <source>Certificates (*.cer *.crt *.pem)</source>
        <translation>Сертификаты (*.pem *.crt *.cer)</translation>
    </message>
    <message>
        <source>Failed to save file</source>
        <translation>Файл не был сохранён</translation>
    </message>
    <message>
        <source>Certificate Information:</source>
        <translation>Информация о сертификате</translation>
    </message>
    <message>
        <source>This certificate is intended for following purpose(s):</source>
        <translation>Предназначение сертификата:</translation>
    </message>
    <message>
        <source>Issued to:</source>
        <translation>Выдан:</translation>
    </message>
    <message>
        <source>Issued by:</source>
        <translation>Выдано:</translation>
    </message>
    <message>
        <source>Valid from</source>
        <translation>Действительно с</translation>
    </message>
    <message>
        <source>to</source>
        <translation>до</translation>
    </message>
    <message>
        <source>Version</source>
        <translation>Версия</translation>
    </message>
    <message>
        <source>Serial number</source>
        <translation>Серийный номер</translation>
    </message>
    <message>
        <source>Signature algorithm</source>
        <translation>Алгоритм подписи</translation>
    </message>
    <message>
        <source>Issuer</source>
        <translation>Выдавший</translation>
    </message>
    <message>
        <source>Vaild to</source>
        <translation>Действительно до</translation>
    </message>
    <message>
        <source>Subject</source>
        <translation>Субъект</translation>
    </message>
    <message>
        <source>Public key</source>
        <translation>Открытый ключ</translation>
    </message>
    <message>
        <source>Enhanched key usage</source>
        <translation>Дополнительное использование ключа</translation>
    </message>
    <message>
        <source>Certificate policies</source>
        <translation>Правила сертификатов</translation>
    </message>
    <message>
        <source>Key usage</source>
        <translation>Использование ключа</translation>
    </message>
    <message>
        <source>Certificate</source>
        <translation>Сертификат</translation>
    </message>
    <message>
        <source>General</source>
        <translation>Общее</translation>
    </message>
    <message>
        <source>Details</source>
        <translation>Детали</translation>
    </message>
    <message>
        <source>Field</source>
        <translation>Поле</translation>
    </message>
    <message>
        <source>Value</source>
        <translation>Значение</translation>
    </message>
    <message>
        <source>Certification Path</source>
        <translation>Путь сертификата</translation>
    </message>
    <message>
        <source>Certificate status:</source>
        <translation>Статус сертификата:</translation>
    </message>
    <message>
        <source>Authority key identifier</source>
        <translation>Идентификатор личного ключа</translation>
    </message>
    <message>
        <source>Subject key identifier</source>
        <translation>Идентификатор ключа заглавия</translation>
    </message>
</context>
<context>
    <name>Common</name>
    <message>
        <source>Company</source>
        <translation>Учереждение</translation>
    </message>
    <message>
        <source>Register code</source>
        <translation>Код регистра</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>Имя</translation>
    </message>
    <message>
        <source>Personal code</source>
        <translation>Личный код</translation>
    </message>
    <message>
        <source>Card in reader</source>
        <translation>Карта в считывателе</translation>
    </message>
    <message>
        <source>Auth certificate is</source>
        <translation>Сертификаты подписи</translation>
    </message>
    <message>
        <source>Sign certificate is</source>
        <translation>Сертификаты подписи</translation>
    </message>
    <message>
        <source>valid</source>
        <translation>действительны</translation>
    </message>
    <message>
        <source>Your certificates will be expire</source>
        <translation>Сертификаты будут недействительны</translation>
    </message>
    <message>
        <source>expired</source>
        <translation>устарели</translation>
    </message>
    <message>
        <source>Open utility</source>
        <translation>Открыть средство управления</translation>
    </message>
</context>
<context>
    <name>PinDialog</name>
    <message>
        <source>Selected action requires auth certificate.</source>
        <translation>Даннаяй опперация требует личный сертификат.</translation>
    </message>
    <message>
        <source>For using auth certificate enter PIN1</source>
        <translation>Для использования сертификата введите PIN1</translation>
    </message>
    <message>
        <source>Selected action requires sign certificate.</source>
        <translation>Для данной опперации необходим сертификат подписи.</translation>
    </message>
    <message>
        <source>For using sign certificate enter PIN2</source>
        <translation>Для использования  сертификата подписи введите PIN1</translation>
    </message>
    <message>
        <source>For using auth certificate enter PIN1 with pinpad</source>
        <translation>Для использования личного сертификата введите PIN1 с клавиатуры считывателя</translation>
    </message>
    <message>
        <source>For using sign certificate enter PIN2 with pinpad</source>
        <translation>Для использования сертификата подписи  введите PIN2 с клавиатуры считывателя</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Proves your identity to a remote computer</source>
        <translation>Подтверждает Вашу личность на отдалённом компьютере</translation>
    </message>
    <message>
        <source>Protects e-mail messages</source>
        <translation>Защищает е-майл сообщения</translation>
    </message>
    <message>
        <source>OCSP signing</source>
        <translation>OCSP подписывание</translation>
    </message>
    <message>
        <source>All application policies</source>
        <translation>Все полисы приложений</translation>
    </message>
    <message>
        <source>Digital signature</source>
        <translation>Дигитальная подпись</translation>
    </message>
    <message>
        <source>Non repudiation</source>
        <translation>Не отрицательно</translation>
    </message>
    <message>
        <source>Key encipherment</source>
        <translation>Зашифровка ключа</translation>
    </message>
    <message>
        <source>Data encipherment</source>
        <translation>Зашифровка данных</translation>
    </message>
    <message>
        <source>Key agreement</source>
        <translation>Подтверждение ключа</translation>
    </message>
    <message>
        <source>Key certificate sign</source>
        <translation>Подпись ключа сертификата</translation>
    </message>
    <message>
        <source>CRL sign</source>
        <translation>CRL подпись</translation>
    </message>
    <message>
        <source>Encipher only</source>
        <translation>Только зашифровка</translation>
    </message>
    <message>
        <source>Decipher only</source>
        <translation>Только разшифровка</translation>
    </message>
    <message>
        <source>failed to load pkcs11 module</source>
        <translation>ошибка при загрузке модуля pkcs11</translation>
    </message>
    <message>
        <source>failed to list slots</source>
        <translation>ошибка при чтении слотов pkcs11</translation>
    </message>
    <message>
        <source>token failed</source>
        <translation>ошибка при загрузке &quot;token&quot;-а</translation>
    </message>
    <message>
        <source>no token available</source>
        <translation>не найдено ни одного &quot;token&quot;-а</translation>
    </message>
    <message>
        <source>no key matching certificate available</source>
        <translation>не найдено подходящего сертификата</translation>
    </message>
    <message>
        <source>Failed to connect to host. Are you connected to the internet?</source>
        <translation>Отсутствует подключение к интернету!</translation>
    </message>
    <message>
        <source>no certificate available</source>
        <translation>Нет доступного сертификата</translation>
    </message>
</context>
</TS>

==> qesteidutil-0.1.99.1724.tar.bz2: qesteidutil-0.1.99.1724/common/translations/common_ru.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="ru">
<context>
    <name>CertificateDialog</name>
    <message>
        <source>Save certificate</source>
        <translation>Сохранить сертификат</translation>
    </message>
    <message>
        <source>Certificates (*.cer *.crt *.pem)</source>
        <translation>Сертификаты (*.pem *.crt *.cer)</translation>
    </message>
    <message>
        <source>Failed to save file</source>
        <translation>Файл не был сохранён</translation>
    </message>
    <message>
        <source>Certificate Information</source>
        <translation>Информация о сертификате</translation>
    </message>
    <message>
        <source>This certificate is intended for following purpose(s):</source>
        <translation>Предназначение сертификата:</translation>
    </message>
    <message>
        <source>Issued to:</source>
        <translation>Выдан:</translation>
    </message>
    <message>
        <source>Issued by:</source>
        <translation>Выдано:</translation>
    </message>
    <message>
        <source>Valid from</source>
        <translation>Действительно с</translation>
    </message>
    <message>
        <source>to</source>
        <translation>до</translation>
    </message>
    <message>
        <source>Version</source>
        <translation>Версия</translation>
    </message>
    <message>
        <source>Serial number</source>
        <translation>Серийный номер</translation>
    </message>
    <message>
        <source>Signature algorithm</source>
        <translation>Алгоритм подписи</translation>
    </message>
    <message>
        <source>Issuer</source>
        <translation>Выдавший</translation>
    </message>
    <message>
        <source>Vaild to</source>
        <translation>Действительно до</translation>
    </message>
    <message>
        <source>Subject</source>
        <translation>Субъект</translation>
    </message>
    <message>
        <source>Public key</source>
        <translation>Открытый ключ</translation>
    </message>
    <message>
        <source>Enhanched key usage</source>
        <translation>Дополнительное использование ключа</translation>
    </message>
    <message>
        <source>Certificate policies</source>
        <translation>Правила сертификатов</translation>
    </message>
    <message>
        <source>Key usage</source>
        <translation>Использование ключа</translation>
    </message>
    <message>
        <source>Certificate</source>
        <translation>Сертификат</translation>
    </message>
    <message>
        <source>General</source>
        <translation>Общее</translation>
    </message>
    <message>
        <source>Details</source>
        <translation>Детали</translation>
    </message>
    <message>
        <source>Field</source>
        <translation>Поле</translation>
    </message>
    <message>
        <source>Value</source>
        <translation>Значение</translation>
    </message>
    <message>
        <source>Certification Path</source>
        <translation>Путь сертификата</translation>
    </message>
    <message>
        <source>Certificate status:</source>
        <translation>Статус сертификата:</translation>
    </message>
    <message>
        <source>Authority key identifier</source>
        <translation>Идентификатор личного ключа</translation>
    </message>
    <message>
        <source>Subject key identifier</source>
        <translation>Идентификатор ключа заглавия</translation>
    </message>
</context>
<context>
    <name>Common</name>
    <message>
        <source>Company</source>
        <translation>Учереждение</translation>
    </message>
    <message>
        <source>Register code</source>
        <translation>Код регистра</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>Имя</translation>
    </message>
    <message>
        <source>Personal code</source>
        <translation>Личный код</translation>
    </message>
    <message>
        <source>Card in reader</source>
        <translation>Карта в считывателе</translation>
    </message>
    <message>
        <source>Auth certificate is</source>
        <translation>Сертификаты подписи</translation>
    </message>
    <message>
        <source>Sign certificate is</source>
        <translation>Сертификаты подписи</translation>
    </message>
    <message>
        <source>valid</source>
        <translation>действительны</translation>
    </message>
    <message>
        <source>Your certificates will be expire</source>
        <translation>Сертификаты будут недействительны</translation>
    </message>
    <message>
        <source>expired</source>
        <translation>устарели</translation>
    </message>
    <message>
        <source>Open utility</source>
        <translation>Открыть средство управления</translation>
    </message>
</context>
<context>
    <name>PinDialog</name>
    <message>
        <source>Selected action requires auth certificate.</source>
        <translation>Даннаяй опперация требует личный сертификат.</translation>
    </message>
    <message>
        <source>For using auth certificate enter PIN1</source>
        <translation>Для использования сертификата введите PIN1</translation>
    </message>
    <message>
        <source>Selected action requires sign certificate.</source>
        <translation>Для данной опперации необходим сертификат подписи.</translation>
    </message>
    <message>
        <source>For using sign certificate enter PIN2</source>
        <translation>Для использования  сертификата подписи введите PIN2</translation>
    </message>
    <message>
        <source>For using auth certificate enter PIN1 with pinpad</source>
        <translation>Для использования личного сертификата введите PIN1 с клавиатуры считывателя</translation>
    </message>
    <message>
        <source>For using sign certificate enter PIN2 with pinpad</source>
        <translation>Для использования сертификата подписи  введите PIN2 с клавиатуры считывателя</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Proves your identity to a remote computer</source>
        <translation>Подтверждает Вашу личность на отдалённом компьютере</translation>
    </message>
    <message>
        <source>Protects e-mail messages</source>
        <translation>Защищает сообщения электронной почты</translation>
    </message>
    <message>
        <source>OCSP signing</source>
        <translation>OCSP подписывание</translation>
    </message>
    <message>
        <source>All application policies</source>
        <translation>Все полисы приложений</translation>
    </message>
    <message>
        <source>Digital signature</source>
        <translation>Дигитальная подпись</translation>
    </message>
    <message>
        <source>Non repudiation</source>
        <translation>Не отрицательно</translation>
    </message>
    <message>
        <source>Key encipherment</source>
        <translation>Зашифровка ключа</translation>
    </message>
    <message>
        <source>Data encipherment</source>
        <translation>Зашифровка данных</translation>
    </message>
    <message>
        <source>Key agreement</source>
        <translation>Подтверждение ключа</translation>
    </message>
    <message>
        <source>Key certificate sign</source>
        <translation>Подпись ключа сертификата</translation>
    </message>
    <message>
        <source>CRL sign</source>
        <translation>CRL подпись</translation>
    </message>
    <message>
        <source>Encipher only</source>
        <translation>Только зашифровка</translation>
    </message>
    <message>
        <source>Decipher only</source>
        <translation>Только разшифровка</translation>
    </message>
    <message>
        <source>failed to load pkcs11 module</source>
        <translation>ошибка при загрузке модуля pkcs11</translation>
    </message>
    <message>
        <source>failed to list slots</source>
        <translation>ошибка при чтении слотов pkcs11</translation>
    </message>
    <message>
        <source>token failed</source>
        <translation>ошибка при загрузке &quot;token&quot;-а</translation>
    </message>
    <message>
        <source>no token available</source>
        <translation>не найдено ни одного &quot;token&quot;-а</translation>
    </message>
    <message>
        <source>no key matching certificate available</source>
        <translation>не найдено подходящего сертификата</translation>
    </message>
    <message>
        <source>Failed to connect to host. Are you connected to the internet?</source>
        <translation>Отсутствует подключение к интернету!</translation>
    </message>
    <message>
        <source>no certificate available</source>
        <translation>Нет доступного сертификата</translation>
    </message>
</context>
</TS>
